# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DimensionalRiskScoreRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'post_score': 'bool',
        'max_answers': 'list[float]',
        'answer_weights': 'list[float]',
        'dims': 'list[str]',
        'client_id': 'str',
        'answers': 'list[float]',
        'dim_weights': 'list[float]',
        'questionnaire_id': 'str',
        'answer_dims': 'list[list[str]]'
    }

    attribute_map = {
        'post_score': 'post_score',
        'max_answers': 'max_answers',
        'answer_weights': 'answer_weights',
        'dims': 'dims',
        'client_id': 'client_id',
        'answers': 'answers',
        'dim_weights': 'dim_weights',
        'questionnaire_id': 'questionnaire_id',
        'answer_dims': 'answer_dims'
    }

    def __init__(self, post_score=False, max_answers=None, answer_weights=None, dims=None, client_id=None, answers=None, dim_weights=None, questionnaire_id=None, answer_dims=None):  # noqa: E501
        """DimensionalRiskScoreRequest - a model defined in Swagger"""  # noqa: E501

        self._post_score = None
        self._max_answers = None
        self._answer_weights = None
        self._dims = None
        self._client_id = None
        self._answers = None
        self._dim_weights = None
        self._questionnaire_id = None
        self._answer_dims = None
        self.discriminator = None

        if post_score is not None:
            self.post_score = post_score
        self.max_answers = max_answers
        if answer_weights is not None:
            self.answer_weights = answer_weights
        self.dims = dims
        if client_id is not None:
            self.client_id = client_id
        if answers is not None:
            self.answers = answers
        if dim_weights is not None:
            self.dim_weights = dim_weights
        if questionnaire_id is not None:
            self.questionnaire_id = questionnaire_id
        self.answer_dims = answer_dims

    @property
    def post_score(self):
        """Gets the post_score of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The post_score of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._post_score

    @post_score.setter
    def post_score(self, post_score):
        """Sets the post_score of this DimensionalRiskScoreRequest.


        :param post_score: The post_score of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: bool
        """

        self._post_score = post_score

    @property
    def max_answers(self):
        """Gets the max_answers of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The max_answers of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._max_answers

    @max_answers.setter
    def max_answers(self, max_answers):
        """Sets the max_answers of this DimensionalRiskScoreRequest.


        :param max_answers: The max_answers of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[float]
        """
        if max_answers is None:
            raise ValueError("Invalid value for `max_answers`, must not be `None`")  # noqa: E501

        self._max_answers = max_answers

    @property
    def answer_weights(self):
        """Gets the answer_weights of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The answer_weights of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._answer_weights

    @answer_weights.setter
    def answer_weights(self, answer_weights):
        """Sets the answer_weights of this DimensionalRiskScoreRequest.


        :param answer_weights: The answer_weights of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._answer_weights = answer_weights

    @property
    def dims(self):
        """Gets the dims of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The dims of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._dims

    @dims.setter
    def dims(self, dims):
        """Sets the dims of this DimensionalRiskScoreRequest.


        :param dims: The dims of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[str]
        """
        if dims is None:
            raise ValueError("Invalid value for `dims`, must not be `None`")  # noqa: E501

        self._dims = dims

    @property
    def client_id(self):
        """Gets the client_id of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The client_id of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this DimensionalRiskScoreRequest.


        :param client_id: The client_id of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def answers(self):
        """Gets the answers of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The answers of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._answers

    @answers.setter
    def answers(self, answers):
        """Sets the answers of this DimensionalRiskScoreRequest.


        :param answers: The answers of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._answers = answers

    @property
    def dim_weights(self):
        """Gets the dim_weights of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The dim_weights of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._dim_weights

    @dim_weights.setter
    def dim_weights(self, dim_weights):
        """Sets the dim_weights of this DimensionalRiskScoreRequest.


        :param dim_weights: The dim_weights of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._dim_weights = dim_weights

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The questionnaire_id of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this DimensionalRiskScoreRequest.


        :param questionnaire_id: The questionnaire_id of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: str
        """

        self._questionnaire_id = questionnaire_id

    @property
    def answer_dims(self):
        """Gets the answer_dims of this DimensionalRiskScoreRequest.  # noqa: E501


        :return: The answer_dims of this DimensionalRiskScoreRequest.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._answer_dims

    @answer_dims.setter
    def answer_dims(self, answer_dims):
        """Sets the answer_dims of this DimensionalRiskScoreRequest.


        :param answer_dims: The answer_dims of this DimensionalRiskScoreRequest.  # noqa: E501
        :type: list[list[str]]
        """
        if answer_dims is None:
            raise ValueError("Invalid value for `answer_dims`, must not be `None`")  # noqa: E501

        self._answer_dims = answer_dims

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DimensionalRiskScoreRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DimensionalRiskScoreRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BusinessFinancialHealthCheckRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'period_length': 'str',
        'net_income': 'float',
        'period_month': 'int',
        'total_revenue': 'float',
        'total_assets': 'float',
        'client_id': 'str',
        'accounting_method': 'str',
        'period_year': 'int',
        'currency_conversion': 'str',
        'total_liabilities': 'float',
        'period_type': 'str',
        'currency_code': 'str',
        'ratio_targets': 'RatioTargets1',
        'total_equity': 'float',
        'period_quarter': 'int'
    }

    attribute_map = {
        'period_length': 'period_length',
        'net_income': 'net_income',
        'period_month': 'period_month',
        'total_revenue': 'total_revenue',
        'total_assets': 'total_assets',
        'client_id': 'client_id',
        'accounting_method': 'accounting_method',
        'period_year': 'period_year',
        'currency_conversion': 'currency_conversion',
        'total_liabilities': 'total_liabilities',
        'period_type': 'period_type',
        'currency_code': 'currency_code',
        'ratio_targets': 'ratio_targets',
        'total_equity': 'total_equity',
        'period_quarter': 'period_quarter'
    }

    def __init__(self, period_length='quarterly', net_income=None, period_month=None, total_revenue=None, total_assets=None, client_id=None, accounting_method=None, period_year=None, currency_conversion=None, total_liabilities=None, period_type=None, currency_code=None, ratio_targets=None, total_equity=None, period_quarter=None):  # noqa: E501
        """BusinessFinancialHealthCheckRequest - a model defined in Swagger"""  # noqa: E501

        self._period_length = None
        self._net_income = None
        self._period_month = None
        self._total_revenue = None
        self._total_assets = None
        self._client_id = None
        self._accounting_method = None
        self._period_year = None
        self._currency_conversion = None
        self._total_liabilities = None
        self._period_type = None
        self._currency_code = None
        self._ratio_targets = None
        self._total_equity = None
        self._period_quarter = None
        self.discriminator = None

        if period_length is not None:
            self.period_length = period_length
        if net_income is not None:
            self.net_income = net_income
        if period_month is not None:
            self.period_month = period_month
        if total_revenue is not None:
            self.total_revenue = total_revenue
        if total_assets is not None:
            self.total_assets = total_assets
        if client_id is not None:
            self.client_id = client_id
        if accounting_method is not None:
            self.accounting_method = accounting_method
        if period_year is not None:
            self.period_year = period_year
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if total_liabilities is not None:
            self.total_liabilities = total_liabilities
        if period_type is not None:
            self.period_type = period_type
        if currency_code is not None:
            self.currency_code = currency_code
        if ratio_targets is not None:
            self.ratio_targets = ratio_targets
        if total_equity is not None:
            self.total_equity = total_equity
        if period_quarter is not None:
            self.period_quarter = period_quarter

    @property
    def period_length(self):
        """Gets the period_length of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The period_length of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_length

    @period_length.setter
    def period_length(self, period_length):
        """Sets the period_length of this BusinessFinancialHealthCheckRequest.


        :param period_length: The period_length of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["annual", "quarterly", "monthly", "ytd", "qtd", "mtd"]  # noqa: E501
        if period_length not in allowed_values:
            raise ValueError(
                "Invalid value for `period_length` ({0}), must be one of {1}"  # noqa: E501
                .format(period_length, allowed_values)
            )

        self._period_length = period_length

    @property
    def net_income(self):
        """Gets the net_income of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The net_income of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._net_income

    @net_income.setter
    def net_income(self, net_income):
        """Sets the net_income of this BusinessFinancialHealthCheckRequest.


        :param net_income: The net_income of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """

        self._net_income = net_income

    @property
    def period_month(self):
        """Gets the period_month of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The period_month of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_month

    @period_month.setter
    def period_month(self, period_month):
        """Sets the period_month of this BusinessFinancialHealthCheckRequest.


        :param period_month: The period_month of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: int
        """
        if period_month is not None and period_month > 12:  # noqa: E501
            raise ValueError("Invalid value for `period_month`, must be a value less than or equal to `12`")  # noqa: E501
        if period_month is not None and period_month < 1:  # noqa: E501
            raise ValueError("Invalid value for `period_month`, must be a value greater than or equal to `1`")  # noqa: E501

        self._period_month = period_month

    @property
    def total_revenue(self):
        """Gets the total_revenue of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The total_revenue of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_revenue

    @total_revenue.setter
    def total_revenue(self, total_revenue):
        """Sets the total_revenue of this BusinessFinancialHealthCheckRequest.


        :param total_revenue: The total_revenue of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if total_revenue is not None and total_revenue < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_revenue`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_revenue = total_revenue

    @property
    def total_assets(self):
        """Gets the total_assets of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The total_assets of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_assets

    @total_assets.setter
    def total_assets(self, total_assets):
        """Sets the total_assets of this BusinessFinancialHealthCheckRequest.


        :param total_assets: The total_assets of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if total_assets is not None and total_assets < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_assets`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_assets = total_assets

    @property
    def client_id(self):
        """Gets the client_id of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The client_id of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BusinessFinancialHealthCheckRequest.


        :param client_id: The client_id of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def accounting_method(self):
        """Gets the accounting_method of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The accounting_method of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._accounting_method

    @accounting_method.setter
    def accounting_method(self, accounting_method):
        """Sets the accounting_method of this BusinessFinancialHealthCheckRequest.


        :param accounting_method: The accounting_method of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["accrual", "cash"]  # noqa: E501
        if accounting_method not in allowed_values:
            raise ValueError(
                "Invalid value for `accounting_method` ({0}), must be one of {1}"  # noqa: E501
                .format(accounting_method, allowed_values)
            )

        self._accounting_method = accounting_method

    @property
    def period_year(self):
        """Gets the period_year of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The period_year of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_year

    @period_year.setter
    def period_year(self, period_year):
        """Sets the period_year of this BusinessFinancialHealthCheckRequest.


        :param period_year: The period_year of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: int
        """

        self._period_year = period_year

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The currency_conversion of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this BusinessFinancialHealthCheckRequest.


        :param currency_conversion: The currency_conversion of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def total_liabilities(self):
        """Gets the total_liabilities of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The total_liabilities of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_liabilities

    @total_liabilities.setter
    def total_liabilities(self, total_liabilities):
        """Sets the total_liabilities of this BusinessFinancialHealthCheckRequest.


        :param total_liabilities: The total_liabilities of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if total_liabilities is not None and total_liabilities < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_liabilities`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_liabilities = total_liabilities

    @property
    def period_type(self):
        """Gets the period_type of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The period_type of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_type

    @period_type.setter
    def period_type(self, period_type):
        """Sets the period_type of this BusinessFinancialHealthCheckRequest.


        :param period_type: The period_type of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["calendar", "fiscal"]  # noqa: E501
        if period_type not in allowed_values:
            raise ValueError(
                "Invalid value for `period_type` ({0}), must be one of {1}"  # noqa: E501
                .format(period_type, allowed_values)
            )

        self._period_type = period_type

    @property
    def currency_code(self):
        """Gets the currency_code of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The currency_code of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this BusinessFinancialHealthCheckRequest.


        :param currency_code: The currency_code of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def ratio_targets(self):
        """Gets the ratio_targets of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The ratio_targets of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: RatioTargets1
        """
        return self._ratio_targets

    @ratio_targets.setter
    def ratio_targets(self, ratio_targets):
        """Sets the ratio_targets of this BusinessFinancialHealthCheckRequest.


        :param ratio_targets: The ratio_targets of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: RatioTargets1
        """

        self._ratio_targets = ratio_targets

    @property
    def total_equity(self):
        """Gets the total_equity of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The total_equity of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_equity

    @total_equity.setter
    def total_equity(self, total_equity):
        """Sets the total_equity of this BusinessFinancialHealthCheckRequest.


        :param total_equity: The total_equity of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if total_equity is not None and total_equity < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_equity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_equity = total_equity

    @property
    def period_quarter(self):
        """Gets the period_quarter of this BusinessFinancialHealthCheckRequest.  # noqa: E501


        :return: The period_quarter of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_quarter

    @period_quarter.setter
    def period_quarter(self, period_quarter):
        """Sets the period_quarter of this BusinessFinancialHealthCheckRequest.


        :param period_quarter: The period_quarter of this BusinessFinancialHealthCheckRequest.  # noqa: E501
        :type: int
        """
        if period_quarter is not None and period_quarter > 4:  # noqa: E501
            raise ValueError("Invalid value for `period_quarter`, must be a value less than or equal to `4`")  # noqa: E501
        if period_quarter is not None and period_quarter < 1:  # noqa: E501
            raise ValueError("Invalid value for `period_quarter`, must be a value greater than or equal to `1`")  # noqa: E501

        self._period_quarter = period_quarter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BusinessFinancialHealthCheckRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessFinancialHealthCheckRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IncomeConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annual_net_take_home_pay': 'float',
        'percentage_of_income_covered': 'float',
        'income_benefit_duration': 'int'
    }

    attribute_map = {
        'annual_net_take_home_pay': 'annual_net_take_home_pay',
        'percentage_of_income_covered': 'percentage_of_income_covered',
        'income_benefit_duration': 'income_benefit_duration'
    }

    def __init__(self, annual_net_take_home_pay=None, percentage_of_income_covered=1.0, income_benefit_duration=10):  # noqa: E501
        """IncomeConfig - a model defined in Swagger"""  # noqa: E501

        self._annual_net_take_home_pay = None
        self._percentage_of_income_covered = None
        self._income_benefit_duration = None
        self.discriminator = None

        self.annual_net_take_home_pay = annual_net_take_home_pay
        if percentage_of_income_covered is not None:
            self.percentage_of_income_covered = percentage_of_income_covered
        if income_benefit_duration is not None:
            self.income_benefit_duration = income_benefit_duration

    @property
    def annual_net_take_home_pay(self):
        """Gets the annual_net_take_home_pay of this IncomeConfig.  # noqa: E501


        :return: The annual_net_take_home_pay of this IncomeConfig.  # noqa: E501
        :rtype: float
        """
        return self._annual_net_take_home_pay

    @annual_net_take_home_pay.setter
    def annual_net_take_home_pay(self, annual_net_take_home_pay):
        """Sets the annual_net_take_home_pay of this IncomeConfig.


        :param annual_net_take_home_pay: The annual_net_take_home_pay of this IncomeConfig.  # noqa: E501
        :type: float
        """
        if annual_net_take_home_pay is None:
            raise ValueError("Invalid value for `annual_net_take_home_pay`, must not be `None`")  # noqa: E501
        if annual_net_take_home_pay is not None and annual_net_take_home_pay < 0:  # noqa: E501
            raise ValueError("Invalid value for `annual_net_take_home_pay`, must be a value greater than or equal to `0`")  # noqa: E501

        self._annual_net_take_home_pay = annual_net_take_home_pay

    @property
    def percentage_of_income_covered(self):
        """Gets the percentage_of_income_covered of this IncomeConfig.  # noqa: E501


        :return: The percentage_of_income_covered of this IncomeConfig.  # noqa: E501
        :rtype: float
        """
        return self._percentage_of_income_covered

    @percentage_of_income_covered.setter
    def percentage_of_income_covered(self, percentage_of_income_covered):
        """Sets the percentage_of_income_covered of this IncomeConfig.


        :param percentage_of_income_covered: The percentage_of_income_covered of this IncomeConfig.  # noqa: E501
        :type: float
        """
        if percentage_of_income_covered is not None and percentage_of_income_covered > 1:  # noqa: E501
            raise ValueError("Invalid value for `percentage_of_income_covered`, must be a value less than or equal to `1`")  # noqa: E501
        if percentage_of_income_covered is not None and percentage_of_income_covered < 0:  # noqa: E501
            raise ValueError("Invalid value for `percentage_of_income_covered`, must be a value greater than or equal to `0`")  # noqa: E501

        self._percentage_of_income_covered = percentage_of_income_covered

    @property
    def income_benefit_duration(self):
        """Gets the income_benefit_duration of this IncomeConfig.  # noqa: E501


        :return: The income_benefit_duration of this IncomeConfig.  # noqa: E501
        :rtype: int
        """
        return self._income_benefit_duration

    @income_benefit_duration.setter
    def income_benefit_duration(self, income_benefit_duration):
        """Sets the income_benefit_duration of this IncomeConfig.


        :param income_benefit_duration: The income_benefit_duration of this IncomeConfig.  # noqa: E501
        :type: int
        """
        if income_benefit_duration is not None and income_benefit_duration < 1:  # noqa: E501
            raise ValueError("Invalid value for `income_benefit_duration`, must be a value greater than or equal to `1`")  # noqa: E501

        self._income_benefit_duration = income_benefit_duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncomeConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncomeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GuaranteedRateBenefit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_period': 'int',
        'end_period': 'int',
        'max_rate': 'float',
        'min_rate': 'float'
    }

    attribute_map = {
        'start_period': 'start_period',
        'end_period': 'end_period',
        'max_rate': 'max_rate',
        'min_rate': 'min_rate'
    }

    def __init__(self, start_period=1, end_period=None, max_rate=None, min_rate=0.0):  # noqa: E501
        """GuaranteedRateBenefit - a model defined in Swagger"""  # noqa: E501

        self._start_period = None
        self._end_period = None
        self._max_rate = None
        self._min_rate = None
        self.discriminator = None

        if start_period is not None:
            self.start_period = start_period
        if end_period is not None:
            self.end_period = end_period
        if max_rate is not None:
            self.max_rate = max_rate
        if min_rate is not None:
            self.min_rate = min_rate

    @property
    def start_period(self):
        """Gets the start_period of this GuaranteedRateBenefit.  # noqa: E501


        :return: The start_period of this GuaranteedRateBenefit.  # noqa: E501
        :rtype: int
        """
        return self._start_period

    @start_period.setter
    def start_period(self, start_period):
        """Sets the start_period of this GuaranteedRateBenefit.


        :param start_period: The start_period of this GuaranteedRateBenefit.  # noqa: E501
        :type: int
        """
        if start_period is not None and start_period < 1:  # noqa: E501
            raise ValueError("Invalid value for `start_period`, must be a value greater than or equal to `1`")  # noqa: E501

        self._start_period = start_period

    @property
    def end_period(self):
        """Gets the end_period of this GuaranteedRateBenefit.  # noqa: E501


        :return: The end_period of this GuaranteedRateBenefit.  # noqa: E501
        :rtype: int
        """
        return self._end_period

    @end_period.setter
    def end_period(self, end_period):
        """Sets the end_period of this GuaranteedRateBenefit.


        :param end_period: The end_period of this GuaranteedRateBenefit.  # noqa: E501
        :type: int
        """
        if end_period is not None and end_period < 1:  # noqa: E501
            raise ValueError("Invalid value for `end_period`, must be a value greater than or equal to `1`")  # noqa: E501

        self._end_period = end_period

    @property
    def max_rate(self):
        """Gets the max_rate of this GuaranteedRateBenefit.  # noqa: E501


        :return: The max_rate of this GuaranteedRateBenefit.  # noqa: E501
        :rtype: float
        """
        return self._max_rate

    @max_rate.setter
    def max_rate(self, max_rate):
        """Sets the max_rate of this GuaranteedRateBenefit.


        :param max_rate: The max_rate of this GuaranteedRateBenefit.  # noqa: E501
        :type: float
        """
        if max_rate is not None and max_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `max_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._max_rate = max_rate

    @property
    def min_rate(self):
        """Gets the min_rate of this GuaranteedRateBenefit.  # noqa: E501


        :return: The min_rate of this GuaranteedRateBenefit.  # noqa: E501
        :rtype: float
        """
        return self._min_rate

    @min_rate.setter
    def min_rate(self, min_rate):
        """Sets the min_rate of this GuaranteedRateBenefit.


        :param min_rate: The min_rate of this GuaranteedRateBenefit.  # noqa: E501
        :type: float
        """
        if min_rate is not None and min_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `min_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._min_rate = min_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GuaranteedRateBenefit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GuaranteedRateBenefit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from proton_api.api_client import ApiClient


class AnnuitiesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def annuity_calculator_accumulation_horizon(self, annuity_calculator_accumulation_horizon_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Accumulation Horizon  # noqa: E501

        Calculate the necessary fixed annuity contribution period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_accumulation_horizon(annuity_calculator_accumulation_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorAccumulationHorizonRequest annuity_calculator_accumulation_horizon_request: Request payload for Annuity Calculator - Accumulation Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.annuity_calculator_accumulation_horizon_with_http_info(annuity_calculator_accumulation_horizon_request, **kwargs)  # noqa: E501
        else:
            (data) = self.annuity_calculator_accumulation_horizon_with_http_info(annuity_calculator_accumulation_horizon_request, **kwargs)  # noqa: E501
            return data

    def annuity_calculator_accumulation_horizon_with_http_info(self, annuity_calculator_accumulation_horizon_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Accumulation Horizon  # noqa: E501

        Calculate the necessary fixed annuity contribution period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_accumulation_horizon_with_http_info(annuity_calculator_accumulation_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorAccumulationHorizonRequest annuity_calculator_accumulation_horizon_request: Request payload for Annuity Calculator - Accumulation Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['annuity_calculator_accumulation_horizon_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method annuity_calculator_accumulation_horizon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'annuity_calculator_accumulation_horizon_request' is set
        if ('annuity_calculator_accumulation_horizon_request' not in params or
                params['annuity_calculator_accumulation_horizon_request'] is None):
            raise ValueError("Missing the required parameter `annuity_calculator_accumulation_horizon_request` when calling `annuity_calculator_accumulation_horizon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'annuity_calculator_accumulation_horizon_request' in params:
            body_params = params['annuity_calculator_accumulation_horizon_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/annuity_calculator/accumulation_horizon', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def annuity_calculator_annuity_amount(self, annuity_calculator_annuity_amount_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Annuity Amount  # noqa: E501

        Calculate the achievable fixed annuity amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_annuity_amount(annuity_calculator_annuity_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorAnnuityAmountRequest annuity_calculator_annuity_amount_request: Request payload for Annuity Calculator - Annuity Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.annuity_calculator_annuity_amount_with_http_info(annuity_calculator_annuity_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.annuity_calculator_annuity_amount_with_http_info(annuity_calculator_annuity_amount_request, **kwargs)  # noqa: E501
            return data

    def annuity_calculator_annuity_amount_with_http_info(self, annuity_calculator_annuity_amount_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Annuity Amount  # noqa: E501

        Calculate the achievable fixed annuity amount  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_annuity_amount_with_http_info(annuity_calculator_annuity_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorAnnuityAmountRequest annuity_calculator_annuity_amount_request: Request payload for Annuity Calculator - Annuity Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['annuity_calculator_annuity_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method annuity_calculator_annuity_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'annuity_calculator_annuity_amount_request' is set
        if ('annuity_calculator_annuity_amount_request' not in params or
                params['annuity_calculator_annuity_amount_request'] is None):
            raise ValueError("Missing the required parameter `annuity_calculator_annuity_amount_request` when calling `annuity_calculator_annuity_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'annuity_calculator_annuity_amount_request' in params:
            body_params = params['annuity_calculator_annuity_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/annuity_calculator/annuity_amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def annuity_calculator_decumulation_horizon(self, annuity_calculator_decumulation_horizon_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Decumulation Horizon  # noqa: E501

        Calculate the achievable fixed annuity payout period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_decumulation_horizon(annuity_calculator_decumulation_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorDecumulationHorizonRequest annuity_calculator_decumulation_horizon_request: Request payload for Annuity Calculator - Decumulation Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.annuity_calculator_decumulation_horizon_with_http_info(annuity_calculator_decumulation_horizon_request, **kwargs)  # noqa: E501
        else:
            (data) = self.annuity_calculator_decumulation_horizon_with_http_info(annuity_calculator_decumulation_horizon_request, **kwargs)  # noqa: E501
            return data

    def annuity_calculator_decumulation_horizon_with_http_info(self, annuity_calculator_decumulation_horizon_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Decumulation Horizon  # noqa: E501

        Calculate the achievable fixed annuity payout period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_decumulation_horizon_with_http_info(annuity_calculator_decumulation_horizon_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorDecumulationHorizonRequest annuity_calculator_decumulation_horizon_request: Request payload for Annuity Calculator - Decumulation Horizon (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['annuity_calculator_decumulation_horizon_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method annuity_calculator_decumulation_horizon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'annuity_calculator_decumulation_horizon_request' is set
        if ('annuity_calculator_decumulation_horizon_request' not in params or
                params['annuity_calculator_decumulation_horizon_request'] is None):
            raise ValueError("Missing the required parameter `annuity_calculator_decumulation_horizon_request` when calling `annuity_calculator_decumulation_horizon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'annuity_calculator_decumulation_horizon_request' in params:
            body_params = params['annuity_calculator_decumulation_horizon_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/annuity_calculator/decumulation_horizon', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def annuity_calculator_deposit_amount(self, annuity_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount for a fixed annuity  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_deposit_amount(annuity_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorDepositAmountRequest annuity_calculator_deposit_amount_request: Request payload for Annuity Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.annuity_calculator_deposit_amount_with_http_info(annuity_calculator_deposit_amount_request, **kwargs)  # noqa: E501
        else:
            (data) = self.annuity_calculator_deposit_amount_with_http_info(annuity_calculator_deposit_amount_request, **kwargs)  # noqa: E501
            return data

    def annuity_calculator_deposit_amount_with_http_info(self, annuity_calculator_deposit_amount_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Deposit Amount  # noqa: E501

        Calculate the necessary periodic deposit amount for a fixed annuity  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_deposit_amount_with_http_info(annuity_calculator_deposit_amount_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorDepositAmountRequest annuity_calculator_deposit_amount_request: Request payload for Annuity Calculator - Deposit Amount (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['annuity_calculator_deposit_amount_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method annuity_calculator_deposit_amount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'annuity_calculator_deposit_amount_request' is set
        if ('annuity_calculator_deposit_amount_request' not in params or
                params['annuity_calculator_deposit_amount_request'] is None):
            raise ValueError("Missing the required parameter `annuity_calculator_deposit_amount_request` when calling `annuity_calculator_deposit_amount`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'annuity_calculator_deposit_amount_request' in params:
            body_params = params['annuity_calculator_deposit_amount_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/annuity_calculator/deposit_amount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def annuity_calculator_initial_balance(self, annuity_calculator_initial_balance_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Initial Balance  # noqa: E501

        Calculate the necessary initial balance for a fixed annuity  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_initial_balance(annuity_calculator_initial_balance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorInitialBalanceRequest annuity_calculator_initial_balance_request: Request payload for Annuity Calculator - Initial Balance (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.annuity_calculator_initial_balance_with_http_info(annuity_calculator_initial_balance_request, **kwargs)  # noqa: E501
        else:
            (data) = self.annuity_calculator_initial_balance_with_http_info(annuity_calculator_initial_balance_request, **kwargs)  # noqa: E501
            return data

    def annuity_calculator_initial_balance_with_http_info(self, annuity_calculator_initial_balance_request, **kwargs):  # noqa: E501
        """Annuity Calculator - Initial Balance  # noqa: E501

        Calculate the necessary initial balance for a fixed annuity  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.annuity_calculator_initial_balance_with_http_info(annuity_calculator_initial_balance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnnuityCalculatorInitialBalanceRequest annuity_calculator_initial_balance_request: Request payload for Annuity Calculator - Initial Balance (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['annuity_calculator_initial_balance_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method annuity_calculator_initial_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'annuity_calculator_initial_balance_request' is set
        if ('annuity_calculator_initial_balance_request' not in params or
                params['annuity_calculator_initial_balance_request'] is None):
            raise ValueError("Missing the required parameter `annuity_calculator_initial_balance_request` when calling `annuity_calculator_initial_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'annuity_calculator_initial_balance_request' in params:
            body_params = params['annuity_calculator_initial_balance_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/annuity_calculator/initial_balance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def variable_annuity(self, variable_annuity_request, **kwargs):  # noqa: E501
        """Variable Annuity  # noqa: E501

        Project the behavior of a variable annuity over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.variable_annuity(variable_annuity_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param VariableAnnuityRequest variable_annuity_request: Request payload for Variable Annuity (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.variable_annuity_with_http_info(variable_annuity_request, **kwargs)  # noqa: E501
        else:
            (data) = self.variable_annuity_with_http_info(variable_annuity_request, **kwargs)  # noqa: E501
            return data

    def variable_annuity_with_http_info(self, variable_annuity_request, **kwargs):  # noqa: E501
        """Variable Annuity  # noqa: E501

        Project the behavior of a variable annuity over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.variable_annuity_with_http_info(variable_annuity_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param VariableAnnuityRequest variable_annuity_request: Request payload for Variable Annuity (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['variable_annuity_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method variable_annuity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'variable_annuity_request' is set
        if ('variable_annuity_request' not in params or
                params['variable_annuity_request'] is None):
            raise ValueError("Missing the required parameter `variable_annuity_request` when calling `variable_annuity`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable_annuity_request' in params:
            body_params = params['variable_annuity_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/variable_annuity', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from proton_api.models.accumulation_goal_deposit_config import AccumulationGoalDepositConfig
from proton_api.models.annuity_calculator_accumulation_horizon_request import AnnuityCalculatorAccumulationHorizonRequest
from proton_api.models.annuity_calculator_annuity_amount_request import AnnuityCalculatorAnnuityAmountRequest
from proton_api.models.annuity_calculator_decumulation_horizon_request import AnnuityCalculatorDecumulationHorizonRequest
from proton_api.models.annuity_calculator_deposit_amount_request import AnnuityCalculatorDepositAmountRequest
from proton_api.models.annuity_calculator_initial_balance_request import AnnuityCalculatorInitialBalanceRequest
from proton_api.models.annuity_deposit_schedule import AnnuityDepositSchedule
from proton_api.models.backtest_request import BacktestRequest
from proton_api.models.beneficiary_bequest_config import BeneficiaryBequestConfig
from proton_api.models.budget_aggregation_account import BudgetAggregationAccount
from proton_api.models.budget_calculator_request import BudgetCalculatorRequest
from proton_api.models.budget_component import BudgetComponent
from proton_api.models.budget_details import BudgetDetails
from proton_api.models.business_financial_health_check_request import BusinessFinancialHealthCheckRequest
from proton_api.models.business_invoice_analysis_request import BusinessInvoiceAnalysisRequest
from proton_api.models.calculator_deposit_schedule import CalculatorDepositSchedule
from proton_api.models.calculator_deposit_schedule1 import CalculatorDepositSchedule1
from proton_api.models.card_limit_check_request import CardLimitCheckRequest
from proton_api.models.card_transaction_authorization_request import CardTransactionAuthorizationRequest
from proton_api.models.cash_analysis_request import CashAnalysisRequest
from proton_api.models.cash_flow_analysis_request import CashFlowAnalysisRequest
from proton_api.models.children_education_config import ChildrenEducationConfig
from proton_api.models.customer_analysis_request import CustomerAnalysisRequest
from proton_api.models.decumulation_goal_deposit_config import DecumulationGoalDepositConfig
from proton_api.models.dimensional_risk_score_request import DimensionalRiskScoreRequest
from proton_api.models.diversification_score_request import DiversificationScoreRequest
from proton_api.models.education_calculator_annual_cost_request import EducationCalculatorAnnualCostRequest
from proton_api.models.education_calculator_deposit_amount_request import EducationCalculatorDepositAmountRequest
from proton_api.models.education_calculator_percent_covered_request import EducationCalculatorPercentCoveredRequest
from proton_api.models.education_config import EducationConfig
from proton_api.models.emergency_fund_calculator_request import EmergencyFundCalculatorRequest
from proton_api.models.event_study_request import EventStudyRequest
from proton_api.models.fee_analysis_request import FeeAnalysisRequest
from proton_api.models.financial_health_check_request import FinancialHealthCheckRequest
from proton_api.models.financial_picture_request import FinancialPictureRequest
from proton_api.models.financial_statement_analysis_request import FinancialStatementAnalysisRequest
from proton_api.models.goal_accumulation_allocation_request import GoalAccumulationAllocationRequest
from proton_api.models.goal_accumulation_recommendation_request import GoalAccumulationRecommendationRequest
from proton_api.models.goal_accumulation_status_request import GoalAccumulationStatusRequest
from proton_api.models.goal_config import GoalConfig
from proton_api.models.goal_decumulation_allocation_request import GoalDecumulationAllocationRequest
from proton_api.models.goal_decumulation_recommendation_request import GoalDecumulationRecommendationRequest
from proton_api.models.goal_decumulation_status_request import GoalDecumulationStatusRequest
from proton_api.models.goal_withdrawal_config import GoalWithdrawalConfig
from proton_api.models.guaranteed_rate_benefit import GuaranteedRateBenefit
from proton_api.models.income_config import IncomeConfig
from proton_api.models.life_insurance_needs_calculator_request import LifeInsuranceNeedsCalculatorRequest
from proton_api.models.monte_carlo_request import MonteCarloRequest
from proton_api.models.mortgage_calculator_down_payment_request import MortgageCalculatorDownPaymentRequest
from proton_api.models.mortgage_calculator_home_price_request import MortgageCalculatorHomePriceRequest
from proton_api.models.mortgage_calculator_periodic_payment_request import MortgageCalculatorPeriodicPaymentRequest
from proton_api.models.mvo_request import MvoRequest
from proton_api.models.opt_config import OptConfig
from proton_api.models.opt_config1 import OptConfig1
from proton_api.models.periods import Periods
from proton_api.models.portfolio_optimization_score_request import PortfolioOptimizationScoreRequest
from proton_api.models.portfolio_what_if_request import PortfolioWhatIfRequest
from proton_api.models.purchase_calculator_amount_request import PurchaseCalculatorAmountRequest
from proton_api.models.purchase_calculator_deposit_amount_request import PurchaseCalculatorDepositAmountRequest
from proton_api.models.purchase_calculator_horizon_request import PurchaseCalculatorHorizonRequest
from proton_api.models.ratio_targets import RatioTargets
from proton_api.models.ratio_targets1 import RatioTargets1
from proton_api.models.rebalancing_signal_request import RebalancingSignalRequest
from proton_api.models.recommendation_config import RecommendationConfig
from proton_api.models.recommendation_config1 import RecommendationConfig1
from proton_api.models.recurring_transaction_analysis_request import RecurringTransactionAnalysisRequest
from proton_api.models.retirement_calculator_deposit_amount_request import RetirementCalculatorDepositAmountRequest
from proton_api.models.retirement_calculator_expenses_request import RetirementCalculatorExpensesRequest
from proton_api.models.retirement_calculator_percent_covered_request import RetirementCalculatorPercentCoveredRequest
from proton_api.models.risk_allocation_request import RiskAllocationRequest
from proton_api.models.risk_score_request import RiskScoreRequest
from proton_api.models.savings_calculator_request import SavingsCalculatorRequest
from proton_api.models.savings_deposit_schedule import SavingsDepositSchedule
from proton_api.models.scenario_analysis_request import ScenarioAnalysisRequest
from proton_api.models.sensitivity_analysis_request import SensitivityAnalysisRequest
from proton_api.models.sensitivity_factor import SensitivityFactor
from proton_api.models.settings import Settings
from proton_api.models.variable_annuity_request import VariableAnnuityRequest
from proton_api.models.w_config import WConfig
from proton_api.models.w_config1 import WConfig1



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RatioTargets1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'profit_margin': 'float',
        'return_on_assets': 'float',
        'debt_to_equity': 'float',
        'return_on_equity': 'float',
        'debt_ratio': 'float',
        'asset_turnover': 'float'
    }

    attribute_map = {
        'profit_margin': 'profit_margin',
        'return_on_assets': 'return_on_assets',
        'debt_to_equity': 'debt_to_equity',
        'return_on_equity': 'return_on_equity',
        'debt_ratio': 'debt_ratio',
        'asset_turnover': 'asset_turnover'
    }

    def __init__(self, profit_margin=0.1, return_on_assets=0.05, debt_to_equity=1.5, return_on_equity=0.15, debt_ratio=0.5, asset_turnover=1.0):  # noqa: E501
        """RatioTargets1 - a model defined in Swagger"""  # noqa: E501

        self._profit_margin = None
        self._return_on_assets = None
        self._debt_to_equity = None
        self._return_on_equity = None
        self._debt_ratio = None
        self._asset_turnover = None
        self.discriminator = None

        if profit_margin is not None:
            self.profit_margin = profit_margin
        if return_on_assets is not None:
            self.return_on_assets = return_on_assets
        if debt_to_equity is not None:
            self.debt_to_equity = debt_to_equity
        if return_on_equity is not None:
            self.return_on_equity = return_on_equity
        if debt_ratio is not None:
            self.debt_ratio = debt_ratio
        if asset_turnover is not None:
            self.asset_turnover = asset_turnover

    @property
    def profit_margin(self):
        """Gets the profit_margin of this RatioTargets1.  # noqa: E501


        :return: The profit_margin of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._profit_margin

    @profit_margin.setter
    def profit_margin(self, profit_margin):
        """Sets the profit_margin of this RatioTargets1.


        :param profit_margin: The profit_margin of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if profit_margin is not None and profit_margin < 0:  # noqa: E501
            raise ValueError("Invalid value for `profit_margin`, must be a value greater than or equal to `0`")  # noqa: E501

        self._profit_margin = profit_margin

    @property
    def return_on_assets(self):
        """Gets the return_on_assets of this RatioTargets1.  # noqa: E501


        :return: The return_on_assets of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._return_on_assets

    @return_on_assets.setter
    def return_on_assets(self, return_on_assets):
        """Sets the return_on_assets of this RatioTargets1.


        :param return_on_assets: The return_on_assets of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if return_on_assets is not None and return_on_assets < 0:  # noqa: E501
            raise ValueError("Invalid value for `return_on_assets`, must be a value greater than or equal to `0`")  # noqa: E501

        self._return_on_assets = return_on_assets

    @property
    def debt_to_equity(self):
        """Gets the debt_to_equity of this RatioTargets1.  # noqa: E501


        :return: The debt_to_equity of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._debt_to_equity

    @debt_to_equity.setter
    def debt_to_equity(self, debt_to_equity):
        """Sets the debt_to_equity of this RatioTargets1.


        :param debt_to_equity: The debt_to_equity of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if debt_to_equity is not None and debt_to_equity < 0:  # noqa: E501
            raise ValueError("Invalid value for `debt_to_equity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._debt_to_equity = debt_to_equity

    @property
    def return_on_equity(self):
        """Gets the return_on_equity of this RatioTargets1.  # noqa: E501


        :return: The return_on_equity of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._return_on_equity

    @return_on_equity.setter
    def return_on_equity(self, return_on_equity):
        """Sets the return_on_equity of this RatioTargets1.


        :param return_on_equity: The return_on_equity of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if return_on_equity is not None and return_on_equity < 0:  # noqa: E501
            raise ValueError("Invalid value for `return_on_equity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._return_on_equity = return_on_equity

    @property
    def debt_ratio(self):
        """Gets the debt_ratio of this RatioTargets1.  # noqa: E501


        :return: The debt_ratio of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._debt_ratio

    @debt_ratio.setter
    def debt_ratio(self, debt_ratio):
        """Sets the debt_ratio of this RatioTargets1.


        :param debt_ratio: The debt_ratio of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if debt_ratio is not None and debt_ratio < 0:  # noqa: E501
            raise ValueError("Invalid value for `debt_ratio`, must be a value greater than or equal to `0`")  # noqa: E501

        self._debt_ratio = debt_ratio

    @property
    def asset_turnover(self):
        """Gets the asset_turnover of this RatioTargets1.  # noqa: E501


        :return: The asset_turnover of this RatioTargets1.  # noqa: E501
        :rtype: float
        """
        return self._asset_turnover

    @asset_turnover.setter
    def asset_turnover(self, asset_turnover):
        """Sets the asset_turnover of this RatioTargets1.


        :param asset_turnover: The asset_turnover of this RatioTargets1.  # noqa: E501
        :type: float
        """
        if asset_turnover is not None and asset_turnover < 0:  # noqa: E501
            raise ValueError("Invalid value for `asset_turnover`, must be a value greater than or equal to `0`")  # noqa: E501

        self._asset_turnover = asset_turnover

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RatioTargets1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RatioTargets1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CashAnalysisRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'date',
        'client_id': 'str',
        'show_inflow_details': 'bool',
        'currency_conversion': 'str',
        'history_frequency_interval': 'str',
        'start_date': 'date',
        'show_history': 'bool',
        'currency_code': 'str',
        'show_outflow_details': 'bool',
        'scope': 'str'
    }

    attribute_map = {
        'end_date': 'end_date',
        'client_id': 'client_id',
        'show_inflow_details': 'show_inflow_details',
        'currency_conversion': 'currency_conversion',
        'history_frequency_interval': 'history_frequency_interval',
        'start_date': 'start_date',
        'show_history': 'show_history',
        'currency_code': 'currency_code',
        'show_outflow_details': 'show_outflow_details',
        'scope': 'scope'
    }

    def __init__(self, end_date=None, client_id=None, show_inflow_details=False, currency_conversion=None, history_frequency_interval='month', start_date=None, show_history=False, currency_code=None, show_outflow_details=False, scope='all'):  # noqa: E501
        """CashAnalysisRequest - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._client_id = None
        self._show_inflow_details = None
        self._currency_conversion = None
        self._history_frequency_interval = None
        self._start_date = None
        self._show_history = None
        self._currency_code = None
        self._show_outflow_details = None
        self._scope = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        if client_id is not None:
            self.client_id = client_id
        if show_inflow_details is not None:
            self.show_inflow_details = show_inflow_details
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if history_frequency_interval is not None:
            self.history_frequency_interval = history_frequency_interval
        if start_date is not None:
            self.start_date = start_date
        if show_history is not None:
            self.show_history = show_history
        if currency_code is not None:
            self.currency_code = currency_code
        if show_outflow_details is not None:
            self.show_outflow_details = show_outflow_details
        if scope is not None:
            self.scope = scope

    @property
    def end_date(self):
        """Gets the end_date of this CashAnalysisRequest.  # noqa: E501


        :return: The end_date of this CashAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CashAnalysisRequest.


        :param end_date: The end_date of this CashAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def client_id(self):
        """Gets the client_id of this CashAnalysisRequest.  # noqa: E501


        :return: The client_id of this CashAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this CashAnalysisRequest.


        :param client_id: The client_id of this CashAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def show_inflow_details(self):
        """Gets the show_inflow_details of this CashAnalysisRequest.  # noqa: E501


        :return: The show_inflow_details of this CashAnalysisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_inflow_details

    @show_inflow_details.setter
    def show_inflow_details(self, show_inflow_details):
        """Sets the show_inflow_details of this CashAnalysisRequest.


        :param show_inflow_details: The show_inflow_details of this CashAnalysisRequest.  # noqa: E501
        :type: bool
        """

        self._show_inflow_details = show_inflow_details

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this CashAnalysisRequest.  # noqa: E501


        :return: The currency_conversion of this CashAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this CashAnalysisRequest.


        :param currency_conversion: The currency_conversion of this CashAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def history_frequency_interval(self):
        """Gets the history_frequency_interval of this CashAnalysisRequest.  # noqa: E501


        :return: The history_frequency_interval of this CashAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._history_frequency_interval

    @history_frequency_interval.setter
    def history_frequency_interval(self, history_frequency_interval):
        """Sets the history_frequency_interval of this CashAnalysisRequest.


        :param history_frequency_interval: The history_frequency_interval of this CashAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["day", "week", "month", "quarter", "year"]  # noqa: E501
        if history_frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `history_frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(history_frequency_interval, allowed_values)
            )

        self._history_frequency_interval = history_frequency_interval

    @property
    def start_date(self):
        """Gets the start_date of this CashAnalysisRequest.  # noqa: E501


        :return: The start_date of this CashAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CashAnalysisRequest.


        :param start_date: The start_date of this CashAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def show_history(self):
        """Gets the show_history of this CashAnalysisRequest.  # noqa: E501


        :return: The show_history of this CashAnalysisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_history

    @show_history.setter
    def show_history(self, show_history):
        """Sets the show_history of this CashAnalysisRequest.


        :param show_history: The show_history of this CashAnalysisRequest.  # noqa: E501
        :type: bool
        """

        self._show_history = show_history

    @property
    def currency_code(self):
        """Gets the currency_code of this CashAnalysisRequest.  # noqa: E501


        :return: The currency_code of this CashAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CashAnalysisRequest.


        :param currency_code: The currency_code of this CashAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def show_outflow_details(self):
        """Gets the show_outflow_details of this CashAnalysisRequest.  # noqa: E501


        :return: The show_outflow_details of this CashAnalysisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_outflow_details

    @show_outflow_details.setter
    def show_outflow_details(self, show_outflow_details):
        """Sets the show_outflow_details of this CashAnalysisRequest.


        :param show_outflow_details: The show_outflow_details of this CashAnalysisRequest.  # noqa: E501
        :type: bool
        """

        self._show_outflow_details = show_outflow_details

    @property
    def scope(self):
        """Gets the scope of this CashAnalysisRequest.  # noqa: E501


        :return: The scope of this CashAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this CashAnalysisRequest.


        :param scope: The scope of this CashAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "external", "internal"]  # noqa: E501
        if scope not in allowed_values:
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CashAnalysisRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CashAnalysisRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BudgetCalculatorRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'as_of_date': 'date',
        'show_budget_track': 'bool',
        'budget_id': 'str',
        'currency_conversion': 'str',
        'lookback_periods': 'int',
        'show_average_spend': 'bool',
        'budget_details': 'BudgetDetails',
        'relative_lookback': 'bool',
        'scope': 'str'
    }

    attribute_map = {
        'as_of_date': 'as_of_date',
        'show_budget_track': 'show_budget_track',
        'budget_id': 'budget_id',
        'currency_conversion': 'currency_conversion',
        'lookback_periods': 'lookback_periods',
        'show_average_spend': 'show_average_spend',
        'budget_details': 'budget_details',
        'relative_lookback': 'relative_lookback',
        'scope': 'scope'
    }

    def __init__(self, as_of_date=None, show_budget_track=True, budget_id=None, currency_conversion=None, lookback_periods=1, show_average_spend=False, budget_details=None, relative_lookback=True, scope='all'):  # noqa: E501
        """BudgetCalculatorRequest - a model defined in Swagger"""  # noqa: E501

        self._as_of_date = None
        self._show_budget_track = None
        self._budget_id = None
        self._currency_conversion = None
        self._lookback_periods = None
        self._show_average_spend = None
        self._budget_details = None
        self._relative_lookback = None
        self._scope = None
        self.discriminator = None

        if as_of_date is not None:
            self.as_of_date = as_of_date
        if show_budget_track is not None:
            self.show_budget_track = show_budget_track
        if budget_id is not None:
            self.budget_id = budget_id
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if lookback_periods is not None:
            self.lookback_periods = lookback_periods
        if show_average_spend is not None:
            self.show_average_spend = show_average_spend
        if budget_details is not None:
            self.budget_details = budget_details
        if relative_lookback is not None:
            self.relative_lookback = relative_lookback
        if scope is not None:
            self.scope = scope

    @property
    def as_of_date(self):
        """Gets the as_of_date of this BudgetCalculatorRequest.  # noqa: E501


        :return: The as_of_date of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: date
        """
        return self._as_of_date

    @as_of_date.setter
    def as_of_date(self, as_of_date):
        """Sets the as_of_date of this BudgetCalculatorRequest.


        :param as_of_date: The as_of_date of this BudgetCalculatorRequest.  # noqa: E501
        :type: date
        """

        self._as_of_date = as_of_date

    @property
    def show_budget_track(self):
        """Gets the show_budget_track of this BudgetCalculatorRequest.  # noqa: E501


        :return: The show_budget_track of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_budget_track

    @show_budget_track.setter
    def show_budget_track(self, show_budget_track):
        """Sets the show_budget_track of this BudgetCalculatorRequest.


        :param show_budget_track: The show_budget_track of this BudgetCalculatorRequest.  # noqa: E501
        :type: bool
        """

        self._show_budget_track = show_budget_track

    @property
    def budget_id(self):
        """Gets the budget_id of this BudgetCalculatorRequest.  # noqa: E501


        :return: The budget_id of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._budget_id

    @budget_id.setter
    def budget_id(self, budget_id):
        """Sets the budget_id of this BudgetCalculatorRequest.


        :param budget_id: The budget_id of this BudgetCalculatorRequest.  # noqa: E501
        :type: str
        """

        self._budget_id = budget_id

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this BudgetCalculatorRequest.  # noqa: E501


        :return: The currency_conversion of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this BudgetCalculatorRequest.


        :param currency_conversion: The currency_conversion of this BudgetCalculatorRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def lookback_periods(self):
        """Gets the lookback_periods of this BudgetCalculatorRequest.  # noqa: E501


        :return: The lookback_periods of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: int
        """
        return self._lookback_periods

    @lookback_periods.setter
    def lookback_periods(self, lookback_periods):
        """Sets the lookback_periods of this BudgetCalculatorRequest.


        :param lookback_periods: The lookback_periods of this BudgetCalculatorRequest.  # noqa: E501
        :type: int
        """
        if lookback_periods is not None and lookback_periods < 1:  # noqa: E501
            raise ValueError("Invalid value for `lookback_periods`, must be a value greater than or equal to `1`")  # noqa: E501

        self._lookback_periods = lookback_periods

    @property
    def show_average_spend(self):
        """Gets the show_average_spend of this BudgetCalculatorRequest.  # noqa: E501


        :return: The show_average_spend of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_average_spend

    @show_average_spend.setter
    def show_average_spend(self, show_average_spend):
        """Sets the show_average_spend of this BudgetCalculatorRequest.


        :param show_average_spend: The show_average_spend of this BudgetCalculatorRequest.  # noqa: E501
        :type: bool
        """

        self._show_average_spend = show_average_spend

    @property
    def budget_details(self):
        """Gets the budget_details of this BudgetCalculatorRequest.  # noqa: E501


        :return: The budget_details of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: BudgetDetails
        """
        return self._budget_details

    @budget_details.setter
    def budget_details(self, budget_details):
        """Sets the budget_details of this BudgetCalculatorRequest.


        :param budget_details: The budget_details of this BudgetCalculatorRequest.  # noqa: E501
        :type: BudgetDetails
        """

        self._budget_details = budget_details

    @property
    def relative_lookback(self):
        """Gets the relative_lookback of this BudgetCalculatorRequest.  # noqa: E501


        :return: The relative_lookback of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: bool
        """
        return self._relative_lookback

    @relative_lookback.setter
    def relative_lookback(self, relative_lookback):
        """Sets the relative_lookback of this BudgetCalculatorRequest.


        :param relative_lookback: The relative_lookback of this BudgetCalculatorRequest.  # noqa: E501
        :type: bool
        """

        self._relative_lookback = relative_lookback

    @property
    def scope(self):
        """Gets the scope of this BudgetCalculatorRequest.  # noqa: E501


        :return: The scope of this BudgetCalculatorRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this BudgetCalculatorRequest.


        :param scope: The scope of this BudgetCalculatorRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "external", "internal"]  # noqa: E501
        if scope not in allowed_values:
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BudgetCalculatorRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BudgetCalculatorRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RatioTargets(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_ratio': 'float',
        'liquidity_ratio_expenses': 'float',
        'liquidity_ratio_liabilities': 'float',
        'savings_ratio_gross': 'float',
        'savings_ratio_net': 'float',
        'asset_allocation_ratio': 'float'
    }

    attribute_map = {
        'current_ratio': 'current_ratio',
        'liquidity_ratio_expenses': 'liquidity_ratio_expenses',
        'liquidity_ratio_liabilities': 'liquidity_ratio_liabilities',
        'savings_ratio_gross': 'savings_ratio_gross',
        'savings_ratio_net': 'savings_ratio_net',
        'asset_allocation_ratio': 'asset_allocation_ratio'
    }

    def __init__(self, current_ratio=0.5, liquidity_ratio_expenses=2.5, liquidity_ratio_liabilities=0.1, savings_ratio_gross=0.1, savings_ratio_net=0.1, asset_allocation_ratio=1.5):  # noqa: E501
        """RatioTargets - a model defined in Swagger"""  # noqa: E501

        self._current_ratio = None
        self._liquidity_ratio_expenses = None
        self._liquidity_ratio_liabilities = None
        self._savings_ratio_gross = None
        self._savings_ratio_net = None
        self._asset_allocation_ratio = None
        self.discriminator = None

        if current_ratio is not None:
            self.current_ratio = current_ratio
        if liquidity_ratio_expenses is not None:
            self.liquidity_ratio_expenses = liquidity_ratio_expenses
        if liquidity_ratio_liabilities is not None:
            self.liquidity_ratio_liabilities = liquidity_ratio_liabilities
        if savings_ratio_gross is not None:
            self.savings_ratio_gross = savings_ratio_gross
        if savings_ratio_net is not None:
            self.savings_ratio_net = savings_ratio_net
        if asset_allocation_ratio is not None:
            self.asset_allocation_ratio = asset_allocation_ratio

    @property
    def current_ratio(self):
        """Gets the current_ratio of this RatioTargets.  # noqa: E501


        :return: The current_ratio of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._current_ratio

    @current_ratio.setter
    def current_ratio(self, current_ratio):
        """Sets the current_ratio of this RatioTargets.


        :param current_ratio: The current_ratio of this RatioTargets.  # noqa: E501
        :type: float
        """
        if current_ratio is not None and current_ratio < 0:  # noqa: E501
            raise ValueError("Invalid value for `current_ratio`, must be a value greater than or equal to `0`")  # noqa: E501

        self._current_ratio = current_ratio

    @property
    def liquidity_ratio_expenses(self):
        """Gets the liquidity_ratio_expenses of this RatioTargets.  # noqa: E501


        :return: The liquidity_ratio_expenses of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._liquidity_ratio_expenses

    @liquidity_ratio_expenses.setter
    def liquidity_ratio_expenses(self, liquidity_ratio_expenses):
        """Sets the liquidity_ratio_expenses of this RatioTargets.


        :param liquidity_ratio_expenses: The liquidity_ratio_expenses of this RatioTargets.  # noqa: E501
        :type: float
        """
        if liquidity_ratio_expenses is not None and liquidity_ratio_expenses < 0:  # noqa: E501
            raise ValueError("Invalid value for `liquidity_ratio_expenses`, must be a value greater than or equal to `0`")  # noqa: E501

        self._liquidity_ratio_expenses = liquidity_ratio_expenses

    @property
    def liquidity_ratio_liabilities(self):
        """Gets the liquidity_ratio_liabilities of this RatioTargets.  # noqa: E501


        :return: The liquidity_ratio_liabilities of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._liquidity_ratio_liabilities

    @liquidity_ratio_liabilities.setter
    def liquidity_ratio_liabilities(self, liquidity_ratio_liabilities):
        """Sets the liquidity_ratio_liabilities of this RatioTargets.


        :param liquidity_ratio_liabilities: The liquidity_ratio_liabilities of this RatioTargets.  # noqa: E501
        :type: float
        """
        if liquidity_ratio_liabilities is not None and liquidity_ratio_liabilities < 0:  # noqa: E501
            raise ValueError("Invalid value for `liquidity_ratio_liabilities`, must be a value greater than or equal to `0`")  # noqa: E501

        self._liquidity_ratio_liabilities = liquidity_ratio_liabilities

    @property
    def savings_ratio_gross(self):
        """Gets the savings_ratio_gross of this RatioTargets.  # noqa: E501


        :return: The savings_ratio_gross of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._savings_ratio_gross

    @savings_ratio_gross.setter
    def savings_ratio_gross(self, savings_ratio_gross):
        """Sets the savings_ratio_gross of this RatioTargets.


        :param savings_ratio_gross: The savings_ratio_gross of this RatioTargets.  # noqa: E501
        :type: float
        """
        if savings_ratio_gross is not None and savings_ratio_gross < 0:  # noqa: E501
            raise ValueError("Invalid value for `savings_ratio_gross`, must be a value greater than or equal to `0`")  # noqa: E501

        self._savings_ratio_gross = savings_ratio_gross

    @property
    def savings_ratio_net(self):
        """Gets the savings_ratio_net of this RatioTargets.  # noqa: E501


        :return: The savings_ratio_net of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._savings_ratio_net

    @savings_ratio_net.setter
    def savings_ratio_net(self, savings_ratio_net):
        """Sets the savings_ratio_net of this RatioTargets.


        :param savings_ratio_net: The savings_ratio_net of this RatioTargets.  # noqa: E501
        :type: float
        """
        if savings_ratio_net is not None and savings_ratio_net < 0:  # noqa: E501
            raise ValueError("Invalid value for `savings_ratio_net`, must be a value greater than or equal to `0`")  # noqa: E501

        self._savings_ratio_net = savings_ratio_net

    @property
    def asset_allocation_ratio(self):
        """Gets the asset_allocation_ratio of this RatioTargets.  # noqa: E501


        :return: The asset_allocation_ratio of this RatioTargets.  # noqa: E501
        :rtype: float
        """
        return self._asset_allocation_ratio

    @asset_allocation_ratio.setter
    def asset_allocation_ratio(self, asset_allocation_ratio):
        """Sets the asset_allocation_ratio of this RatioTargets.


        :param asset_allocation_ratio: The asset_allocation_ratio of this RatioTargets.  # noqa: E501
        :type: float
        """
        if asset_allocation_ratio is not None and asset_allocation_ratio < 0:  # noqa: E501
            raise ValueError("Invalid value for `asset_allocation_ratio`, must be a value greater than or equal to `0`")  # noqa: E501

        self._asset_allocation_ratio = asset_allocation_ratio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RatioTargets, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RatioTargets):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VariableAnnuityRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'portfolio_id': 'str',
        'result_type': 'str',
        'inflation_rate': 'float',
        'remove_outliers': 'bool',
        'deposit_schedule': 'AnnuityDepositSchedule',
        'annuitization_rate': 'float',
        'end_date': 'str',
        'market_data_source': 'str',
        'tax_rate': 'float',
        'p': 'float',
        'allocation_id': 'str',
        'use_proxy_data': 'bool',
        'start_date': 'str',
        'aggregation_account_id': 'str',
        'initial_balance': 'float',
        'create_log': 'bool',
        'decumulation_horizon': 'int',
        'account_id': 'str',
        'accumulation_horizon': 'int',
        'trading_days_per_year': 'int',
        'portfolio_weights': 'list[float]',
        'guaranteed_accumulation_benefit': 'float',
        'portfolio_tickers': 'list[str]',
        'guaranteed_rate_benefit': 'list[GuaranteedRateBenefit]',
        'model_id': 'str',
        'n': 'int',
        'frequency_interval': 'str'
    }

    attribute_map = {
        'portfolio_id': 'portfolio_id',
        'result_type': 'result_type',
        'inflation_rate': 'inflation_rate',
        'remove_outliers': 'remove_outliers',
        'deposit_schedule': 'deposit_schedule',
        'annuitization_rate': 'annuitization_rate',
        'end_date': 'end_date',
        'market_data_source': 'market_data_source',
        'tax_rate': 'tax_rate',
        'p': 'p',
        'allocation_id': 'allocation_id',
        'use_proxy_data': 'use_proxy_data',
        'start_date': 'start_date',
        'aggregation_account_id': 'aggregation_account_id',
        'initial_balance': 'initial_balance',
        'create_log': 'create_log',
        'decumulation_horizon': 'decumulation_horizon',
        'account_id': 'account_id',
        'accumulation_horizon': 'accumulation_horizon',
        'trading_days_per_year': 'trading_days_per_year',
        'portfolio_weights': 'portfolio_weights',
        'guaranteed_accumulation_benefit': 'guaranteed_accumulation_benefit',
        'portfolio_tickers': 'portfolio_tickers',
        'guaranteed_rate_benefit': 'guaranteed_rate_benefit',
        'model_id': 'model_id',
        'n': 'n',
        'frequency_interval': 'frequency_interval'
    }

    def __init__(self, portfolio_id=None, result_type='median', inflation_rate=0.0, remove_outliers=False, deposit_schedule=None, annuitization_rate=0.0, end_date=None, market_data_source='nucleus', tax_rate=0.0, p=None, allocation_id=None, use_proxy_data=False, start_date=None, aggregation_account_id=None, initial_balance=0.0, create_log=False, decumulation_horizon=None, account_id=None, accumulation_horizon=None, trading_days_per_year=252, portfolio_weights=None, guaranteed_accumulation_benefit=0.0, portfolio_tickers=None, guaranteed_rate_benefit=None, model_id=None, n=1000, frequency_interval='year'):  # noqa: E501
        """VariableAnnuityRequest - a model defined in Swagger"""  # noqa: E501

        self._portfolio_id = None
        self._result_type = None
        self._inflation_rate = None
        self._remove_outliers = None
        self._deposit_schedule = None
        self._annuitization_rate = None
        self._end_date = None
        self._market_data_source = None
        self._tax_rate = None
        self._p = None
        self._allocation_id = None
        self._use_proxy_data = None
        self._start_date = None
        self._aggregation_account_id = None
        self._initial_balance = None
        self._create_log = None
        self._decumulation_horizon = None
        self._account_id = None
        self._accumulation_horizon = None
        self._trading_days_per_year = None
        self._portfolio_weights = None
        self._guaranteed_accumulation_benefit = None
        self._portfolio_tickers = None
        self._guaranteed_rate_benefit = None
        self._model_id = None
        self._n = None
        self._frequency_interval = None
        self.discriminator = None

        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if result_type is not None:
            self.result_type = result_type
        if inflation_rate is not None:
            self.inflation_rate = inflation_rate
        if remove_outliers is not None:
            self.remove_outliers = remove_outliers
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule
        if annuitization_rate is not None:
            self.annuitization_rate = annuitization_rate
        if end_date is not None:
            self.end_date = end_date
        if market_data_source is not None:
            self.market_data_source = market_data_source
        if tax_rate is not None:
            self.tax_rate = tax_rate
        if p is not None:
            self.p = p
        if allocation_id is not None:
            self.allocation_id = allocation_id
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        if start_date is not None:
            self.start_date = start_date
        if aggregation_account_id is not None:
            self.aggregation_account_id = aggregation_account_id
        if initial_balance is not None:
            self.initial_balance = initial_balance
        if create_log is not None:
            self.create_log = create_log
        self.decumulation_horizon = decumulation_horizon
        if account_id is not None:
            self.account_id = account_id
        self.accumulation_horizon = accumulation_horizon
        if trading_days_per_year is not None:
            self.trading_days_per_year = trading_days_per_year
        if portfolio_weights is not None:
            self.portfolio_weights = portfolio_weights
        if guaranteed_accumulation_benefit is not None:
            self.guaranteed_accumulation_benefit = guaranteed_accumulation_benefit
        if portfolio_tickers is not None:
            self.portfolio_tickers = portfolio_tickers
        if guaranteed_rate_benefit is not None:
            self.guaranteed_rate_benefit = guaranteed_rate_benefit
        if model_id is not None:
            self.model_id = model_id
        if n is not None:
            self.n = n
        if frequency_interval is not None:
            self.frequency_interval = frequency_interval

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this VariableAnnuityRequest.  # noqa: E501


        :return: The portfolio_id of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this VariableAnnuityRequest.


        :param portfolio_id: The portfolio_id of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._portfolio_id = portfolio_id

    @property
    def result_type(self):
        """Gets the result_type of this VariableAnnuityRequest.  # noqa: E501


        :return: The result_type of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._result_type

    @result_type.setter
    def result_type(self, result_type):
        """Sets the result_type of this VariableAnnuityRequest.


        :param result_type: The result_type of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["mean", "median", "custom"]  # noqa: E501
        if result_type not in allowed_values:
            raise ValueError(
                "Invalid value for `result_type` ({0}), must be one of {1}"  # noqa: E501
                .format(result_type, allowed_values)
            )

        self._result_type = result_type

    @property
    def inflation_rate(self):
        """Gets the inflation_rate of this VariableAnnuityRequest.  # noqa: E501


        :return: The inflation_rate of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._inflation_rate

    @inflation_rate.setter
    def inflation_rate(self, inflation_rate):
        """Sets the inflation_rate of this VariableAnnuityRequest.


        :param inflation_rate: The inflation_rate of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if inflation_rate is not None and inflation_rate > 20:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value less than or equal to `20`")  # noqa: E501
        if inflation_rate is not None and inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._inflation_rate = inflation_rate

    @property
    def remove_outliers(self):
        """Gets the remove_outliers of this VariableAnnuityRequest.  # noqa: E501


        :return: The remove_outliers of this VariableAnnuityRequest.  # noqa: E501
        :rtype: bool
        """
        return self._remove_outliers

    @remove_outliers.setter
    def remove_outliers(self, remove_outliers):
        """Sets the remove_outliers of this VariableAnnuityRequest.


        :param remove_outliers: The remove_outliers of this VariableAnnuityRequest.  # noqa: E501
        :type: bool
        """

        self._remove_outliers = remove_outliers

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this VariableAnnuityRequest.  # noqa: E501


        :return: The deposit_schedule of this VariableAnnuityRequest.  # noqa: E501
        :rtype: AnnuityDepositSchedule
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this VariableAnnuityRequest.


        :param deposit_schedule: The deposit_schedule of this VariableAnnuityRequest.  # noqa: E501
        :type: AnnuityDepositSchedule
        """

        self._deposit_schedule = deposit_schedule

    @property
    def annuitization_rate(self):
        """Gets the annuitization_rate of this VariableAnnuityRequest.  # noqa: E501


        :return: The annuitization_rate of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._annuitization_rate

    @annuitization_rate.setter
    def annuitization_rate(self, annuitization_rate):
        """Sets the annuitization_rate of this VariableAnnuityRequest.


        :param annuitization_rate: The annuitization_rate of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if annuitization_rate is not None and annuitization_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `annuitization_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._annuitization_rate = annuitization_rate

    @property
    def end_date(self):
        """Gets the end_date of this VariableAnnuityRequest.  # noqa: E501


        :return: The end_date of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this VariableAnnuityRequest.


        :param end_date: The end_date of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def market_data_source(self):
        """Gets the market_data_source of this VariableAnnuityRequest.  # noqa: E501


        :return: The market_data_source of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this VariableAnnuityRequest.


        :param market_data_source: The market_data_source of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def tax_rate(self):
        """Gets the tax_rate of this VariableAnnuityRequest.  # noqa: E501


        :return: The tax_rate of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, tax_rate):
        """Sets the tax_rate of this VariableAnnuityRequest.


        :param tax_rate: The tax_rate of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if tax_rate is not None and tax_rate > 1:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value less than or equal to `1`")  # noqa: E501
        if tax_rate is not None and tax_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._tax_rate = tax_rate

    @property
    def p(self):
        """Gets the p of this VariableAnnuityRequest.  # noqa: E501


        :return: The p of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._p

    @p.setter
    def p(self, p):
        """Sets the p of this VariableAnnuityRequest.


        :param p: The p of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if p is not None and p > 100:  # noqa: E501
            raise ValueError("Invalid value for `p`, must be a value less than or equal to `100`")  # noqa: E501
        if p is not None and p < 0:  # noqa: E501
            raise ValueError("Invalid value for `p`, must be a value greater than or equal to `0`")  # noqa: E501

        self._p = p

    @property
    def allocation_id(self):
        """Gets the allocation_id of this VariableAnnuityRequest.  # noqa: E501


        :return: The allocation_id of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_id

    @allocation_id.setter
    def allocation_id(self, allocation_id):
        """Sets the allocation_id of this VariableAnnuityRequest.


        :param allocation_id: The allocation_id of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._allocation_id = allocation_id

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this VariableAnnuityRequest.  # noqa: E501


        :return: The use_proxy_data of this VariableAnnuityRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this VariableAnnuityRequest.


        :param use_proxy_data: The use_proxy_data of this VariableAnnuityRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def start_date(self):
        """Gets the start_date of this VariableAnnuityRequest.  # noqa: E501


        :return: The start_date of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this VariableAnnuityRequest.


        :param start_date: The start_date of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def aggregation_account_id(self):
        """Gets the aggregation_account_id of this VariableAnnuityRequest.  # noqa: E501


        :return: The aggregation_account_id of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_account_id

    @aggregation_account_id.setter
    def aggregation_account_id(self, aggregation_account_id):
        """Sets the aggregation_account_id of this VariableAnnuityRequest.


        :param aggregation_account_id: The aggregation_account_id of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._aggregation_account_id = aggregation_account_id

    @property
    def initial_balance(self):
        """Gets the initial_balance of this VariableAnnuityRequest.  # noqa: E501


        :return: The initial_balance of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._initial_balance

    @initial_balance.setter
    def initial_balance(self, initial_balance):
        """Sets the initial_balance of this VariableAnnuityRequest.


        :param initial_balance: The initial_balance of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if initial_balance is not None and initial_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `initial_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._initial_balance = initial_balance

    @property
    def create_log(self):
        """Gets the create_log of this VariableAnnuityRequest.  # noqa: E501


        :return: The create_log of this VariableAnnuityRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this VariableAnnuityRequest.


        :param create_log: The create_log of this VariableAnnuityRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def decumulation_horizon(self):
        """Gets the decumulation_horizon of this VariableAnnuityRequest.  # noqa: E501


        :return: The decumulation_horizon of this VariableAnnuityRequest.  # noqa: E501
        :rtype: int
        """
        return self._decumulation_horizon

    @decumulation_horizon.setter
    def decumulation_horizon(self, decumulation_horizon):
        """Sets the decumulation_horizon of this VariableAnnuityRequest.


        :param decumulation_horizon: The decumulation_horizon of this VariableAnnuityRequest.  # noqa: E501
        :type: int
        """
        if decumulation_horizon is None:
            raise ValueError("Invalid value for `decumulation_horizon`, must not be `None`")  # noqa: E501
        if decumulation_horizon is not None and decumulation_horizon < 1:  # noqa: E501
            raise ValueError("Invalid value for `decumulation_horizon`, must be a value greater than or equal to `1`")  # noqa: E501

        self._decumulation_horizon = decumulation_horizon

    @property
    def account_id(self):
        """Gets the account_id of this VariableAnnuityRequest.  # noqa: E501


        :return: The account_id of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this VariableAnnuityRequest.


        :param account_id: The account_id of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def accumulation_horizon(self):
        """Gets the accumulation_horizon of this VariableAnnuityRequest.  # noqa: E501


        :return: The accumulation_horizon of this VariableAnnuityRequest.  # noqa: E501
        :rtype: int
        """
        return self._accumulation_horizon

    @accumulation_horizon.setter
    def accumulation_horizon(self, accumulation_horizon):
        """Sets the accumulation_horizon of this VariableAnnuityRequest.


        :param accumulation_horizon: The accumulation_horizon of this VariableAnnuityRequest.  # noqa: E501
        :type: int
        """
        if accumulation_horizon is None:
            raise ValueError("Invalid value for `accumulation_horizon`, must not be `None`")  # noqa: E501
        if accumulation_horizon is not None and accumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `accumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._accumulation_horizon = accumulation_horizon

    @property
    def trading_days_per_year(self):
        """Gets the trading_days_per_year of this VariableAnnuityRequest.  # noqa: E501


        :return: The trading_days_per_year of this VariableAnnuityRequest.  # noqa: E501
        :rtype: int
        """
        return self._trading_days_per_year

    @trading_days_per_year.setter
    def trading_days_per_year(self, trading_days_per_year):
        """Sets the trading_days_per_year of this VariableAnnuityRequest.


        :param trading_days_per_year: The trading_days_per_year of this VariableAnnuityRequest.  # noqa: E501
        :type: int
        """
        if trading_days_per_year is not None and trading_days_per_year < 1:  # noqa: E501
            raise ValueError("Invalid value for `trading_days_per_year`, must be a value greater than or equal to `1`")  # noqa: E501

        self._trading_days_per_year = trading_days_per_year

    @property
    def portfolio_weights(self):
        """Gets the portfolio_weights of this VariableAnnuityRequest.  # noqa: E501


        :return: The portfolio_weights of this VariableAnnuityRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._portfolio_weights

    @portfolio_weights.setter
    def portfolio_weights(self, portfolio_weights):
        """Sets the portfolio_weights of this VariableAnnuityRequest.


        :param portfolio_weights: The portfolio_weights of this VariableAnnuityRequest.  # noqa: E501
        :type: list[float]
        """

        self._portfolio_weights = portfolio_weights

    @property
    def guaranteed_accumulation_benefit(self):
        """Gets the guaranteed_accumulation_benefit of this VariableAnnuityRequest.  # noqa: E501


        :return: The guaranteed_accumulation_benefit of this VariableAnnuityRequest.  # noqa: E501
        :rtype: float
        """
        return self._guaranteed_accumulation_benefit

    @guaranteed_accumulation_benefit.setter
    def guaranteed_accumulation_benefit(self, guaranteed_accumulation_benefit):
        """Sets the guaranteed_accumulation_benefit of this VariableAnnuityRequest.


        :param guaranteed_accumulation_benefit: The guaranteed_accumulation_benefit of this VariableAnnuityRequest.  # noqa: E501
        :type: float
        """
        if guaranteed_accumulation_benefit is not None and guaranteed_accumulation_benefit < 0:  # noqa: E501
            raise ValueError("Invalid value for `guaranteed_accumulation_benefit`, must be a value greater than or equal to `0`")  # noqa: E501

        self._guaranteed_accumulation_benefit = guaranteed_accumulation_benefit

    @property
    def portfolio_tickers(self):
        """Gets the portfolio_tickers of this VariableAnnuityRequest.  # noqa: E501


        :return: The portfolio_tickers of this VariableAnnuityRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._portfolio_tickers

    @portfolio_tickers.setter
    def portfolio_tickers(self, portfolio_tickers):
        """Sets the portfolio_tickers of this VariableAnnuityRequest.


        :param portfolio_tickers: The portfolio_tickers of this VariableAnnuityRequest.  # noqa: E501
        :type: list[str]
        """

        self._portfolio_tickers = portfolio_tickers

    @property
    def guaranteed_rate_benefit(self):
        """Gets the guaranteed_rate_benefit of this VariableAnnuityRequest.  # noqa: E501


        :return: The guaranteed_rate_benefit of this VariableAnnuityRequest.  # noqa: E501
        :rtype: list[GuaranteedRateBenefit]
        """
        return self._guaranteed_rate_benefit

    @guaranteed_rate_benefit.setter
    def guaranteed_rate_benefit(self, guaranteed_rate_benefit):
        """Sets the guaranteed_rate_benefit of this VariableAnnuityRequest.


        :param guaranteed_rate_benefit: The guaranteed_rate_benefit of this VariableAnnuityRequest.  # noqa: E501
        :type: list[GuaranteedRateBenefit]
        """

        self._guaranteed_rate_benefit = guaranteed_rate_benefit

    @property
    def model_id(self):
        """Gets the model_id of this VariableAnnuityRequest.  # noqa: E501


        :return: The model_id of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this VariableAnnuityRequest.


        :param model_id: The model_id of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def n(self):
        """Gets the n of this VariableAnnuityRequest.  # noqa: E501


        :return: The n of this VariableAnnuityRequest.  # noqa: E501
        :rtype: int
        """
        return self._n

    @n.setter
    def n(self, n):
        """Sets the n of this VariableAnnuityRequest.


        :param n: The n of this VariableAnnuityRequest.  # noqa: E501
        :type: int
        """
        if n is not None and n < 1:  # noqa: E501
            raise ValueError("Invalid value for `n`, must be a value greater than or equal to `1`")  # noqa: E501

        self._n = n

    @property
    def frequency_interval(self):
        """Gets the frequency_interval of this VariableAnnuityRequest.  # noqa: E501


        :return: The frequency_interval of this VariableAnnuityRequest.  # noqa: E501
        :rtype: str
        """
        return self._frequency_interval

    @frequency_interval.setter
    def frequency_interval(self, frequency_interval):
        """Sets the frequency_interval of this VariableAnnuityRequest.


        :param frequency_interval: The frequency_interval of this VariableAnnuityRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "quarter", "month", "week", "day"]  # noqa: E501
        if frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(frequency_interval, allowed_values)
            )

        self._frequency_interval = frequency_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VariableAnnuityRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VariableAnnuityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Settings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'drift_rebal': 'bool',
        'downside': 'bool',
        'default_drift_factor': 'float',
        'period_rebal': 'bool',
        'rebalance_period': 'int',
        'tax_efficiency_id': 'int'
    }

    attribute_map = {
        'drift_rebal': 'drift_rebal',
        'downside': 'downside',
        'default_drift_factor': 'default_drift_factor',
        'period_rebal': 'period_rebal',
        'rebalance_period': 'rebalance_period',
        'tax_efficiency_id': 'tax_efficiency_id'
    }

    def __init__(self, drift_rebal=None, downside=None, default_drift_factor=None, period_rebal=None, rebalance_period=None, tax_efficiency_id=None):  # noqa: E501
        """Settings - a model defined in Swagger"""  # noqa: E501

        self._drift_rebal = None
        self._downside = None
        self._default_drift_factor = None
        self._period_rebal = None
        self._rebalance_period = None
        self._tax_efficiency_id = None
        self.discriminator = None

        if drift_rebal is not None:
            self.drift_rebal = drift_rebal
        if downside is not None:
            self.downside = downside
        if default_drift_factor is not None:
            self.default_drift_factor = default_drift_factor
        if period_rebal is not None:
            self.period_rebal = period_rebal
        if rebalance_period is not None:
            self.rebalance_period = rebalance_period
        if tax_efficiency_id is not None:
            self.tax_efficiency_id = tax_efficiency_id

    @property
    def drift_rebal(self):
        """Gets the drift_rebal of this Settings.  # noqa: E501


        :return: The drift_rebal of this Settings.  # noqa: E501
        :rtype: bool
        """
        return self._drift_rebal

    @drift_rebal.setter
    def drift_rebal(self, drift_rebal):
        """Sets the drift_rebal of this Settings.


        :param drift_rebal: The drift_rebal of this Settings.  # noqa: E501
        :type: bool
        """

        self._drift_rebal = drift_rebal

    @property
    def downside(self):
        """Gets the downside of this Settings.  # noqa: E501


        :return: The downside of this Settings.  # noqa: E501
        :rtype: bool
        """
        return self._downside

    @downside.setter
    def downside(self, downside):
        """Sets the downside of this Settings.


        :param downside: The downside of this Settings.  # noqa: E501
        :type: bool
        """

        self._downside = downside

    @property
    def default_drift_factor(self):
        """Gets the default_drift_factor of this Settings.  # noqa: E501


        :return: The default_drift_factor of this Settings.  # noqa: E501
        :rtype: float
        """
        return self._default_drift_factor

    @default_drift_factor.setter
    def default_drift_factor(self, default_drift_factor):
        """Sets the default_drift_factor of this Settings.


        :param default_drift_factor: The default_drift_factor of this Settings.  # noqa: E501
        :type: float
        """
        if default_drift_factor is not None and default_drift_factor < 0:  # noqa: E501
            raise ValueError("Invalid value for `default_drift_factor`, must be a value greater than or equal to `0`")  # noqa: E501

        self._default_drift_factor = default_drift_factor

    @property
    def period_rebal(self):
        """Gets the period_rebal of this Settings.  # noqa: E501


        :return: The period_rebal of this Settings.  # noqa: E501
        :rtype: bool
        """
        return self._period_rebal

    @period_rebal.setter
    def period_rebal(self, period_rebal):
        """Sets the period_rebal of this Settings.


        :param period_rebal: The period_rebal of this Settings.  # noqa: E501
        :type: bool
        """

        self._period_rebal = period_rebal

    @property
    def rebalance_period(self):
        """Gets the rebalance_period of this Settings.  # noqa: E501


        :return: The rebalance_period of this Settings.  # noqa: E501
        :rtype: int
        """
        return self._rebalance_period

    @rebalance_period.setter
    def rebalance_period(self, rebalance_period):
        """Sets the rebalance_period of this Settings.


        :param rebalance_period: The rebalance_period of this Settings.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4]  # noqa: E501
        if rebalance_period not in allowed_values:
            raise ValueError(
                "Invalid value for `rebalance_period` ({0}), must be one of {1}"  # noqa: E501
                .format(rebalance_period, allowed_values)
            )

        self._rebalance_period = rebalance_period

    @property
    def tax_efficiency_id(self):
        """Gets the tax_efficiency_id of this Settings.  # noqa: E501


        :return: The tax_efficiency_id of this Settings.  # noqa: E501
        :rtype: int
        """
        return self._tax_efficiency_id

    @tax_efficiency_id.setter
    def tax_efficiency_id(self, tax_efficiency_id):
        """Sets the tax_efficiency_id of this Settings.


        :param tax_efficiency_id: The tax_efficiency_id of this Settings.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4]  # noqa: E501
        if tax_efficiency_id not in allowed_values:
            raise ValueError(
                "Invalid value for `tax_efficiency_id` ({0}), must be one of {1}"  # noqa: E501
                .format(tax_efficiency_id, allowed_values)
            )

        self._tax_efficiency_id = tax_efficiency_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Settings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Settings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.financial_health_api import FinancialHealthApi  # noqa: E501
from proton_api.rest import ApiException


class TestFinancialHealthApi(unittest.TestCase):
    """FinancialHealthApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.financial_health_api.FinancialHealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_diversification_score(self):
        """Test case for diversification_score

        Diversification Score  # noqa: E501
        """
        pass

    def test_emergency_fund_calculator(self):
        """Test case for emergency_fund_calculator

        Emergency Fund Calculator  # noqa: E501
        """
        pass

    def test_financial_health_check(self):
        """Test case for financial_health_check

        Financial Health Check  # noqa: E501
        """
        pass

    def test_portfolio_optimization_score(self):
        """Test case for portfolio_optimization_score

        Portfolio Optimization Score  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
